  /********************************************************************\
  * BitlBee -- An IRC to other IM-networks gateway                     *
  *                                                                    *
  * Copyright 2002-2004 Wilmer van der Gaast and others                *
  \********************************************************************/

/* INI file reading code						*/

/*
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License with
  the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
  Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _INI_H
#define _INI_H

#ifndef MAX_STRING
#define MAX_STRING 128
#endif

typedef struct
{
	FILE *fp;
	int line;
	char c_section[MAX_STRING];
	char section[MAX_STRING];
	char key[MAX_STRING];
	char value[MAX_STRING];
} ini_t;

ini_t *ini_open( char *file );
int ini_read( ini_t *file );
void ini_close( ini_t *file );

#endif
